
//------------------------------------------------------------------------------
// <auto-generated>
//     This code was generated by a dotnet run from src\ResGen folder.
//     To add or remove a member, edit your .resx file then rerun src\ResGen.
//
//     Changes to this file may cause incorrect behavior and will be lost if
//     the code is regenerated.
// </auto-generated>
//------------------------------------------------------------------------------


using System;
using System.Reflection;

/// <summary>
///   A strongly-typed resource class, for looking up localized strings, etc.
/// </summary>
[global::System.CodeDom.Compiler.GeneratedCodeAttribute("System.Resources.Tools.StronglyTypedResourceBuilder", "4.0.0.0")]
[global::System.Diagnostics.DebuggerNonUserCodeAttribute()]
[global::System.Runtime.CompilerServices.CompilerGeneratedAttribute()]

internal class ParserStrings {

    private static global::System.Resources.ResourceManager resourceMan;

    private static global::System.Globalization.CultureInfo resourceCulture;

    /// <summary>constructor</summary>
    [global::System.Diagnostics.CodeAnalysis.SuppressMessageAttribute("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode")]
    internal ParserStrings() {
    }

    /// <summary>
    ///   Returns the cached ResourceManager instance used by this class.
    /// </summary>
    [global::System.ComponentModel.EditorBrowsableAttribute(global::System.ComponentModel.EditorBrowsableState.Advanced)]
    internal static global::System.Resources.ResourceManager ResourceManager {
        get {
            if (resourceMan is null) {
                global::System.Resources.ResourceManager temp = new global::System.Resources.ResourceManager("System.Management.Automation.resources.ParserStrings", typeof(ParserStrings).Assembly);
                resourceMan = temp;
            }

            return resourceMan;
        }
    }

    /// <summary>
    ///   Overrides the current threads CurrentUICulture property for all
    ///   resource lookups using this strongly typed resource class.
    /// </summary>
    [global::System.ComponentModel.EditorBrowsableAttribute(global::System.ComponentModel.EditorBrowsableState.Advanced)]
    internal static global::System.Globalization.CultureInfo Culture {
        get {
            return resourceCulture;
        }

        set {
            resourceCulture = value;
        }
    }
    

    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Unable to find type [{0}].
    ///  
    /// </summary>
    internal static string TypeNotFound {
        get {
            return ResourceManager.GetString("TypeNotFound", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Unable to find type [{0}]. Details: {1}
    ///  
    /// </summary>
    internal static string TypeNotFoundWithMessage {
        get {
            return ResourceManager.GetString("TypeNotFoundWithMessage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Incomplete string token.
    ///  
    /// </summary>
    internal static string IncompleteString {
        get {
            return ResourceManager.GetString("IncompleteString", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The Unicode escape sequence is not valid. A valid sequence is `u{ followed by one to six hex digits and a closing '}'.
    ///  
    /// </summary>
    internal static string InvalidUnicodeEscapeSequence {
        get {
            return ResourceManager.GetString("InvalidUnicodeEscapeSequence", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The Unicode escape sequence value is out of range. The maximum value is 0x10FFFF.
    ///  
    /// </summary>
    internal static string InvalidUnicodeEscapeSequenceValue {
        get {
            return ResourceManager.GetString("InvalidUnicodeEscapeSequenceValue", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The Unicode escape sequence is missing the closing '}'.
    ///  
    /// </summary>
    internal static string MissingUnicodeEscapeSequenceTerminator {
        get {
            return ResourceManager.GetString("MissingUnicodeEscapeSequenceTerminator", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The Unicode escape sequence contains more than the maximum of six hex digits between braces.
    ///  
    /// </summary>
    internal static string TooManyDigitsInUnicodeEscapeSequence {
        get {
            return ResourceManager.GetString("TooManyDigitsInUnicodeEscapeSequence", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot use [ref] with other types in a type constraint.
    ///  
    /// </summary>
    internal static string ReferenceNeedsToBeByItselfInTypeConstraint {
        get {
            return ResourceManager.GetString("ReferenceNeedsToBeByItselfInTypeConstraint", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    [ref] can only be the final type in type conversion sequence.
    ///  
    /// </summary>
    internal static string ReferenceNeedsToBeLastTypeInTypeConversion {
        get {
            return ResourceManager.GetString("ReferenceNeedsToBeLastTypeInTypeConversion", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot have two occurrences of [ref] in a type sequence.
    ///  
    /// </summary>
    internal static string ReferenceNeedsToBeByItselfInTypeSequence {
        get {
            return ResourceManager.GetString("ReferenceNeedsToBeByItselfInTypeSequence", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The numeric constant {0} is not valid.
    ///  
    /// </summary>
    internal static string BadNumericConstant {
        get {
            return ResourceManager.GetString("BadNumericConstant", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The regular expression pattern {0} is not valid.
    ///  
    /// </summary>
    internal static string InvalidRegularExpression {
        get {
            return ResourceManager.GetString("InvalidRegularExpression", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    An empty ${} variable reference was found. A name is required inside the braces.
    ///  
    /// </summary>
    internal static string EmptyVariableReference {
        get {
            return ResourceManager.GetString("EmptyVariableReference", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Variable reference is not valid. '$' was not followed by a valid variable name character. Consider using ${} to delimit the name.
    ///  
    /// </summary>
    internal static string InvalidVariableReference {
        get {
            return ResourceManager.GetString("InvalidVariableReference", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    You cannot call a method on a null-valued expression.
    ///  
    /// </summary>
    internal static string InvokeMethodOnNull {
        get {
            return ResourceManager.GetString("InvokeMethodOnNull", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Method invocation failed because [{0}] does not contain a method named '{1}'.
    ///  
    /// </summary>
    internal static string MethodNotFound {
        get {
            return ResourceManager.GetString("MethodNotFound", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Assignment failed because [{0}] does not contain a property '{1}()' that can be set.
    ///  
    /// </summary>
    internal static string ParameterizedPropertyAssignmentFailed {
        get {
            return ResourceManager.GetString("ParameterizedPropertyAssignmentFailed", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Unexpected token '{0}' in expression or statement.
    ///  
    /// </summary>
    internal static string UnexpectedToken {
        get {
            return ResourceManager.GetString("UnexpectedToken", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The splatting operator '@' cannot be used to reference variables in an expression. '@{0}' can be used only as an argument to a command. To reference variables in an expression use '${0}'.
    ///  
    /// </summary>
    internal static string SplattingNotPermitted {
        get {
            return ResourceManager.GetString("SplattingNotPermitted", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Parameter '{0}' is not valid
    ///  
    /// </summary>
    internal static string InvalidParameter {
        get {
            return ResourceManager.GetString("InvalidParameter", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing expression after '{0}' in pipeline element.
    ///  
    /// </summary>
    internal static string MissingExpression {
        get {
            return ResourceManager.GetString("MissingExpression", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The expression after '{0}' in a pipeline element produced an object that was not valid. It must result in a command name, a script block, or a CommandInfo object.
    ///  
    /// </summary>
    internal static string BadExpression {
        get {
            return ResourceManager.GetString("BadExpression", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Parameter {0} requires an argument.
    ///  
    /// </summary>
    internal static string ParameterRequiresArgument {
        get {
            return ResourceManager.GetString("ParameterRequiresArgument", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Parameter {0} cannot have an argument.
    ///  
    /// </summary>
    internal static string ParameterCannotHaveArgument {
        get {
            return ResourceManager.GetString("ParameterCannotHaveArgument", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Duplicate parameter ${0} in parameter list.
    ///  
    /// </summary>
    internal static string DuplicateFormalParameter {
        get {
            return ResourceManager.GetString("DuplicateFormalParameter", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing argument in parameter list.
    ///  
    /// </summary>
    internal static string MissingArgument {
        get {
            return ResourceManager.GetString("MissingArgument", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Splatted variables like '@{0}' cannot be part of a comma-separated list of arguments.
    ///  
    /// </summary>
    internal static string SplattingNotPermittedInArgumentList {
        get {
            return ResourceManager.GetString("SplattingNotPermittedInArgumentList", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing file specification after redirection operator.
    ///  
    /// </summary>
    internal static string MissingFileSpecification {
        get {
            return ResourceManager.GetString("MissingFileSpecification", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The '{0}' operator is reserved for future use.
    ///  
    /// </summary>
    internal static string RedirectionNotSupported {
        get {
            return ResourceManager.GetString("RedirectionNotSupported", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Redirection to '{0}' failed: {1}
    ///  
    /// </summary>
    internal static string RedirectionFailed {
        get {
            return ResourceManager.GetString("RedirectionFailed", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Expressions are only allowed as the first element of a pipeline.
    ///  
    /// </summary>
    internal static string ExpressionsMustBeFirstInPipeline {
        get {
            return ResourceManager.GetString("ExpressionsMustBeFirstInPipeline", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    An empty pipe element is not allowed.
    ///  
    /// </summary>
    internal static string EmptyPipeElement {
        get {
            return ResourceManager.GetString("EmptyPipeElement", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The assignment expression is not valid. The input to an assignment operator must be an object that is able to accept assignments, such as a variable or a property.
    ///  
    /// </summary>
    internal static string InvalidLeftHandSide {
        get {
            return ResourceManager.GetString("InvalidLeftHandSide", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A hash table can only be added to another hash table.
    ///  
    /// </summary>
    internal static string AddHashTableToNonHashTable {
        get {
            return ResourceManager.GetString("AddHashTableToNonHashTable", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The right operand of '-is' must be a type.
    ///  
    /// </summary>
    internal static string IsOperatorRequiresType {
        get {
            return ResourceManager.GetString("IsOperatorRequiresType", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The right operand of '-as' must be a type.
    ///  
    /// </summary>
    internal static string AsOperatorRequiresType {
        get {
            return ResourceManager.GetString("AsOperatorRequiresType", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Error formatting a string: {0}.
    ///  
    /// </summary>
    internal static string FormatError {
        get {
            return ResourceManager.GetString("FormatError", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The argument to operator '{0}' is not valid: {1}.
    ///  
    /// </summary>
    internal static string BadOperatorArgument {
        get {
            return ResourceManager.GetString("BadOperatorArgument", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The '{0}' operator failed: {1}.
    ///  
    /// </summary>
    internal static string OperatorFailed {
        get {
            return ResourceManager.GetString("OperatorFailed", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The {0} operator allows only two elements to follow it, not {1}.
    ///  
    /// </summary>
    internal static string BadReplaceArgument {
        get {
            return ResourceManager.GetString("BadReplaceArgument", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    You must provide a value expression following the '{0}' operator.
    ///  
    /// </summary>
    internal static string ExpectedValueExpression {
        get {
            return ResourceManager.GetString("ExpectedValueExpression", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The '{0}' operator works only on variables or on properties.
    ///  
    /// </summary>
    internal static string OperatorRequiresVariableOrProperty {
        get {
            return ResourceManager.GetString("OperatorRequiresVariableOrProperty", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The {0} attribute can be specified only on a hash literal node.
    ///  
    /// </summary>
    internal static string OrderedAttributeOnlyOnHashLiteralNode {
        get {
            return ResourceManager.GetString("OrderedAttributeOnlyOnHashLiteralNode", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Array index expression is missing or not valid.
    ///  
    /// </summary>
    internal static string MissingArrayIndexExpression {
        get {
            return ResourceManager.GetString("MissingArrayIndexExpression", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing property name after reference operator.
    ///  
    /// </summary>
    internal static string MissingPropertyName {
        get {
            return ResourceManager.GetString("MissingPropertyName", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The property '{0}' cannot be found on this object. Verify that the property exists and can be set.
    ///  
    /// </summary>
    internal static string PropertyNotFound {
        get {
            return ResourceManager.GetString("PropertyNotFound", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The property '{0}' cannot be found on this object. Verify that the property exists.
    ///  
    /// </summary>
    internal static string PropertyNotFoundStrict {
        get {
            return ResourceManager.GetString("PropertyNotFoundStrict", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Index operation failed; the array index evaluated to null.
    ///  
    /// </summary>
    internal static string NullArrayIndex {
        get {
            return ResourceManager.GetString("NullArrayIndex", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot index into a null array.
    ///  
    /// </summary>
    internal static string NullArray {
        get {
            return ResourceManager.GetString("NullArray", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Unable to index into an object of type "{0}".
    ///  
    /// </summary>
    internal static string CannotIndex {
        get {
            return ResourceManager.GetString("CannotIndex", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Unable to index into an object of type "{0}" with the ByRef-like return type "{1}". ByRef-like types are not supported in PowerShell.
    ///  
    /// </summary>
    internal static string CannotIndexWithByRefLikeReturnType {
        get {
            return ResourceManager.GetString("CannotIndexWithByRefLikeReturnType", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The array has too many dimensions: {0}. The number of dimensions for an array must be less than or equal to 32.
    ///  
    /// </summary>
    internal static string ArrayHasTooManyDimensions {
        get {
            return ResourceManager.GetString("ArrayHasTooManyDimensions", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Array assignment to [{0}] failed because assignment to slices is not supported.
    ///  
    /// </summary>
    internal static string ArraySliceAssignmentFailed {
        get {
            return ResourceManager.GetString("ArraySliceAssignmentFailed", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    You cannot index into a {0} dimensional array with index [{1}].
    ///  
    /// </summary>
    internal static string NeedMultidimensionalIndex {
        get {
            return ResourceManager.GetString("NeedMultidimensionalIndex", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Array assignment failed because index '{0}' was out of range.
    ///  
    /// </summary>
    internal static string IndexOutOfRange {
        get {
            return ResourceManager.GetString("IndexOutOfRange", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing expression after '{0}'.
    ///  
    /// </summary>
    internal static string MissingExpressionAfterToken {
        get {
            return ResourceManager.GetString("MissingExpressionAfterToken", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    ${{variable}} reference starting is missing the closing '}}'.
    ///  
    /// </summary>
    internal static string IncompleteDollarVariableReference {
        get {
            return ResourceManager.GetString("IncompleteDollarVariableReference", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    $(subexpression) is missing the closing ')'.
    ///  
    /// </summary>
    internal static string IncompleteDollarSubexpressionReference {
        get {
            return ResourceManager.GetString("IncompleteDollarSubexpressionReference", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Internal error - unexpected unary operator {0}.
    ///  
    /// </summary>
    internal static string UnexpectedUnaryOperator {
        get {
            return ResourceManager.GetString("UnexpectedUnaryOperator", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    [ref] cannot be applied to a variable that does not exist.
    ///  
    /// </summary>
    internal static string NonExistingVariableReference {
        get {
            return ResourceManager.GetString("NonExistingVariableReference", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The variable '${0}' cannot be retrieved because it has not been set.
    ///  
    /// </summary>
    internal static string VariableIsUndefined {
        get {
            return ResourceManager.GetString("VariableIsUndefined", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Duplicate keys '{0}' are not allowed in hash literals.
    ///  
    /// </summary>
    internal static string DuplicateKeyInHashLiteral {
        get {
            return ResourceManager.GetString("DuplicateKeyInHashLiteral", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Duplicate named arguments '{0}' are not allowed.
    ///  
    /// </summary>
    internal static string DuplicateNamedArgument {
        get {
            return ResourceManager.GetString("DuplicateNamedArgument", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The '{0}' operator works only on numbers. The operand is a '{1}'.
    ///  
    /// </summary>
    internal static string OperatorRequiresNumber {
        get {
            return ResourceManager.GetString("OperatorRequiresNumber", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    An expression was expected after '('.
    ///  
    /// </summary>
    internal static string ExpectedExpression {
        get {
            return ResourceManager.GetString("ExpectedExpression", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing '=' operator after key in hash literal.
    ///  
    /// </summary>
    internal static string MissingEqualsInHashLiteral {
        get {
            return ResourceManager.GetString("MissingEqualsInHashLiteral", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing statement after '=' in hash literal.
    ///  
    /// </summary>
    internal static string MissingStatementInHashLiteral {
        get {
            return ResourceManager.GetString("MissingStatementInHashLiteral", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing statement after '=' in named argument.
    ///  
    /// </summary>
    internal static string MissingExpressionInNamedArgument {
        get {
            return ResourceManager.GetString("MissingExpressionInNamedArgument", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing ';' or end-of-line in property definition.
    ///  
    /// </summary>
    internal static string MissingPropertyTerminator {
        get {
            return ResourceManager.GetString("MissingPropertyTerminator", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing expression after unary operator '{0}'.
    ///  
    /// </summary>
    internal static string MissingExpressionAfterOperator {
        get {
            return ResourceManager.GetString("MissingExpressionAfterOperator", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing condition in if statement after '{0} ('.
    ///  
    /// </summary>
    internal static string IfStatementMissingCondition {
        get {
            return ResourceManager.GetString("IfStatementMissingCondition", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing statement block after {0} ( condition ).
    ///  
    /// </summary>
    internal static string MissingStatementBlock {
        get {
            return ResourceManager.GetString("MissingStatementBlock", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing statement block after 'else' keyword.
    ///  
    /// </summary>
    internal static string MissingStatementBlockAfterElse {
        get {
            return ResourceManager.GetString("MissingStatementBlockAfterElse", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The file could not be read: {0}.
    ///  
    /// </summary>
    internal static string FileReadError {
        get {
            return ResourceManager.GetString("FileReadError", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The current provider ({0}) cannot open a file.
    ///  
    /// </summary>
    internal static string FileOpenError {
        get {
            return ResourceManager.GetString("FileOpenError", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    No files matching '{0}' were found.
    ///  
    /// </summary>
    internal static string FileNotFound {
        get {
            return ResourceManager.GetString("FileNotFound", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The path cannot be processed because it resolved to more than one file; only one file at a time can be processed.
    ///  
    /// </summary>
    internal static string AmbiguousPath {
        get {
            return ResourceManager.GetString("AmbiguousPath", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The {0} '-{1}' parameter is reserved for future use.
    ///  
    /// </summary>
    internal static string KeywordParameterReservedForFutureUse {
        get {
            return ResourceManager.GetString("KeywordParameterReservedForFutureUse", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot process the 'switch' statement because of a missing file name argument to the -file option.
    ///  
    /// </summary>
    internal static string MissingFilenameOption {
        get {
            return ResourceManager.GetString("MissingFilenameOption", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The file name argument to -file in the switch statement is not valid.
    ///  
    /// </summary>
    internal static string InvalidFilenameOption {
        get {
            return ResourceManager.GetString("InvalidFilenameOption", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The parameter {0} is not valid for the switch statement.
    ///  
    /// </summary>
    internal static string InvalidSwitchFlag {
        get {
            return ResourceManager.GetString("InvalidSwitchFlag", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The parameter {0} is not valid for the foreach statement.
    ///  
    /// </summary>
    internal static string InvalidForeachFlag {
        get {
            return ResourceManager.GetString("InvalidForeachFlag", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A switch statement must have one of the following:  '-file file_name' or '( expression )'.
    ///  
    /// </summary>
    internal static string PipelineValueRequired {
        get {
            return ResourceManager.GetString("PipelineValueRequired", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing condition in switch statement clause.
    ///  
    /// </summary>
    internal static string MissingSwitchConditionExpression {
        get {
            return ResourceManager.GetString("MissingSwitchConditionExpression", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A switch statement can have only one default clause.
    ///  
    /// </summary>
    internal static string MultipleSwitchDefaultClauses {
        get {
            return ResourceManager.GetString("MultipleSwitchDefaultClauses", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing statement block in switch statement clause.
    ///  
    /// </summary>
    internal static string MissingSwitchStatementClause {
        get {
            return ResourceManager.GetString("MissingSwitchStatementClause", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing expression in foreach loop.
    ///The correct form is: foreach ($a in $b) {...}
    ///  
    /// </summary>
    internal static string MissingForeachExpression {
        get {
            return ResourceManager.GetString("MissingForeachExpression", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing statement body in foreach loop.
    ///The correct form is: foreach ($a in $b) {...}
    ///  
    /// </summary>
    internal static string MissingForeachStatement {
        get {
            return ResourceManager.GetString("MissingForeachStatement", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The param statement cannot be used if arguments were specified in the function declaration.
    ///  
    /// </summary>
    internal static string OnlyOneParameterListAllowed {
        get {
            return ResourceManager.GetString("OnlyOneParameterListAllowed", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The operation '[{0}] {1} [{2}]' is not defined.
    ///  
    /// </summary>
    internal static string NotADefinedOperationForType {
        get {
            return ResourceManager.GetString("NotADefinedOperationForType", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    An error occurred while enumerating through a collection: {0}.
    ///  
    /// </summary>
    internal static string BadEnumeration {
        get {
            return ResourceManager.GetString("BadEnumeration", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    An unhandled COM interop exception occurred: {0}
    ///  
    /// </summary>
    internal static string COMException {
        get {
            return ResourceManager.GetString("COMException", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A COM object was accessed after it was already released: {0}
    ///  
    /// </summary>
    internal static string InvalidComObjectException {
        get {
            return ResourceManager.GetString("InvalidComObjectException", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Processing was stopped because the script is too complex.
    ///  
    /// </summary>
    internal static string ScriptTooComplicated {
        get {
            return ResourceManager.GetString("ScriptTooComplicated", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The syntax is not supported by this runspace. This can occur if the runspace is in no-language mode.
    ///  
    /// </summary>
    internal static string ScriptsNotAllowed {
        get {
            return ResourceManager.GetString("ScriptsNotAllowed", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The combination of options with the -split operator is not valid.
    ///  
    /// </summary>
    internal static string InvalidSplitOptionCombination {
        get {
            return ResourceManager.GetString("InvalidSplitOptionCombination", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Options are not allowed on the -split operator with a predicate.
    ///  
    /// </summary>
    internal static string InvalidSplitOptionWithPredicate {
        get {
            return ResourceManager.GetString("InvalidSplitOptionWithPredicate", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The token '{0}' is not a valid statement separator in this version.
    ///  
    /// </summary>
    internal static string InvalidEndOfLine {
        get {
            return ResourceManager.GetString("InvalidEndOfLine", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The '{0}' keyword is not supported in this version of the language.
    ///  
    /// </summary>
    internal static string ReservedKeywordNotAllowed {
        get {
            return ResourceManager.GetString("ReservedKeywordNotAllowed", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing expression after '{0}' in loop.
    ///  
    /// </summary>
    internal static string MissingExpressionAfterKeyword {
        get {
            return ResourceManager.GetString("MissingExpressionAfterKeyword", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing statement body in {0} loop.
    ///  
    /// </summary>
    internal static string MissingLoopStatement {
        get {
            return ResourceManager.GetString("MissingLoopStatement", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The 'trap' statement was incomplete. A trap statement requires a body.
    ///  
    /// </summary>
    internal static string MissingTrapStatement {
        get {
            return ResourceManager.GetString("MissingTrapStatement", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Incomplete 'try' statement. A try statement requires a body.
    ///  
    /// </summary>
    internal static string MissingTryStatement {
        get {
            return ResourceManager.GetString("MissingTryStatement", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Parameter declarations are a comma-separated list of variable names with optional initializer expressions.
    ///  
    /// </summary>
    internal static string InvalidFunctionParameter {
        get {
            return ResourceManager.GetString("InvalidFunctionParameter", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing function body in function declaration.
    ///  
    /// </summary>
    internal static string MissingFunctionBody {
        get {
            return ResourceManager.GetString("MissingFunctionBody", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Script command clause '{0}' has already been defined.
    ///  
    /// </summary>
    internal static string DuplicateScriptCommandClause {
        get {
            return ResourceManager.GetString("DuplicateScriptCommandClause", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    unexpected token '{0}', expected 'begin', 'process', 'end', 'clean', or 'dynamicparam'.
    ///  
    /// </summary>
    internal static string MissingNamedBlocks {
        get {
            return ResourceManager.GetString("MissingNamedBlocks", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing closing '}' in statement block or type definition.
    ///  
    /// </summary>
    internal static string MissingEndCurlyBrace {
        get {
            return ResourceManager.GetString("MissingEndCurlyBrace", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing ')' in method call.
    ///  
    /// </summary>
    internal static string MissingEndParenthesisInMethodCall {
        get {
            return ResourceManager.GetString("MissingEndParenthesisInMethodCall", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing ']' after array index expression.
    ///  
    /// </summary>
    internal static string MissingEndSquareBracket {
        get {
            return ResourceManager.GetString("MissingEndSquareBracket", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing closing ')' in expression.
    ///  
    /// </summary>
    internal static string MissingEndParenthesisInExpression {
        get {
            return ResourceManager.GetString("MissingEndParenthesisInExpression", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing closing ')' in subexpression.
    ///  
    /// </summary>
    internal static string MissingEndParenthesisInSubexpression {
        get {
            return ResourceManager.GetString("MissingEndParenthesisInSubexpression", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing '(' after '{0}' in if statement.
    ///  
    /// </summary>
    internal static string MissingOpenParenthesisInIfStatement {
        get {
            return ResourceManager.GetString("MissingOpenParenthesisInIfStatement", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing ')' after expression in switch statement.
    ///  
    /// </summary>
    internal static string MissingEndParenthesisInSwitchStatement {
        get {
            return ResourceManager.GetString("MissingEndParenthesisInSwitchStatement", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing '{' in switch statement.
    ///  
    /// </summary>
    internal static string MissingCurlyBraceInSwitchStatement {
        get {
            return ResourceManager.GetString("MissingCurlyBraceInSwitchStatement", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing variable name after foreach.
    ///The correct form is: foreach ($a in $b) {...}
    ///  
    /// </summary>
    internal static string MissingVariableNameAfterForeach {
        get {
            return ResourceManager.GetString("MissingVariableNameAfterForeach", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing 'in' after variable in foreach loop.
    ///The correct form is: foreach ($a in $b) {...}
    ///  
    /// </summary>
    internal static string MissingInInForeach {
        get {
            return ResourceManager.GetString("MissingInInForeach", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing closing ')' after expression part of foreach loop.
    ///The correct form is: foreach ($a in $b) {...}
    ///  
    /// </summary>
    internal static string MissingEndParenthesisAfterForeach {
        get {
            return ResourceManager.GetString("MissingEndParenthesisAfterForeach", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing opening '(' after keyword '{0}'.
    ///  
    /// </summary>
    internal static string MissingOpenParenthesisAfterKeyword {
        get {
            return ResourceManager.GetString("MissingOpenParenthesisAfterKeyword", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing while or until keyword in do loop.
    ///  
    /// </summary>
    internal static string MissingWhileOrUntilInDoWhile {
        get {
            return ResourceManager.GetString("MissingWhileOrUntilInDoWhile", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing closing ')' after expression in '{0}' statement.
    ///  
    /// </summary>
    internal static string MissingEndParenthesisAfterStatement {
        get {
            return ResourceManager.GetString("MissingEndParenthesisAfterStatement", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing name after {0} keyword.
    ///  
    /// </summary>
    internal static string MissingNameAfterKeyword {
        get {
            return ResourceManager.GetString("MissingNameAfterKeyword", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing ')' in function parameter list.
    ///  
    /// </summary>
    internal static string MissingEndParenthesisInFunctionParameterList {
        get {
            return ResourceManager.GetString("MissingEndParenthesisInFunctionParameterList", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    An error '{0}' occurred while processing this script. Text describing this error could not be loaded.
    ///  
    /// </summary>
    internal static string BackupParserMessage {
        get {
            return ResourceManager.GetString("BackupParserMessage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    An error '{0}' occurred while processing this script. Text describing this error could not be loaded due to error '{1}'.
    ///  
    /// </summary>
    internal static string BackupParserMessageWithException {
        get {
            return ResourceManager.GetString("BackupParserMessageWithException", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    There is no Runspace available to run scripts in this thread. You can provide one in the DefaultRunspace property of the System.Management.Automation.Runspaces.Runspace type. The script block you attempted to invoke was: {0}
    ///  
    /// </summary>
    internal static string ScriptBlockDelegateInvokedFromWrongThread {
        get {
            return ResourceManager.GetString("ScriptBlockDelegateInvokedFromWrongThread", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Unrecognized token in source text.
    ///  
    /// </summary>
    internal static string UnrecognizedToken {
        get {
            return ResourceManager.GetString("UnrecognizedToken", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Action to take for this exception:
    ///  
    /// </summary>
    internal static string ExceptionActionPromptCaption {
        get {
            return ResourceManager.GetString("ExceptionActionPromptCaption", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    &Continue
    ///  
    /// </summary>
    internal static string ContinueLabel {
        get {
            return ResourceManager.GetString("ContinueLabel", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Report the error then continue with the next script statement.
    ///  
    /// </summary>
    internal static string ContinueHelpMessage {
        get {
            return ResourceManager.GetString("ContinueHelpMessage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    S&ilently Continue
    ///  
    /// </summary>
    internal static string SilentlyContinueLabel {
        get {
            return ResourceManager.GetString("SilentlyContinueLabel", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Do not report this error, just continue with the next script statement.
    ///  
    /// </summary>
    internal static string SilentlyContinueHelpMessage {
        get {
            return ResourceManager.GetString("SilentlyContinueHelpMessage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    &Break
    ///  
    /// </summary>
    internal static string BreakLabel {
        get {
            return ResourceManager.GetString("BreakLabel", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Do not continue processing, throw the exception instead.
    ///  
    /// </summary>
    internal static string BreakHelpMessage {
        get {
            return ResourceManager.GetString("BreakHelpMessage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    &Suspend
    ///  
    /// </summary>
    internal static string SuspendLabel {
        get {
            return ResourceManager.GetString("SuspendLabel", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Pause the current pipeline and return to the command prompt. Type exit to resume operation when you are done.
    ///  
    /// </summary>
    internal static string SuspendHelpMessage {
        get {
            return ResourceManager.GetString("SuspendHelpMessage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot run a document in the middle of a pipeline: {0}.
    ///  
    /// </summary>
    internal static string CantActivateDocumentInPipeline {
        get {
            return ResourceManager.GetString("CantActivateDocumentInPipeline", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Program '{0}' failed to run: {1}{2}.
    ///  
    /// </summary>
    internal static string ProgramFailedToExecute {
        get {
            return ResourceManager.GetString("ProgramFailedToExecute", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot use '&' to invoke in the context of binary module '{0}'. Specify a non-binary module after the '&' and try the operation again.
    ///  
    /// </summary>
    internal static string CantInvokeInBinaryModule {
        get {
            return ResourceManager.GetString("CantInvokeInBinaryModule", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot use '&' to invoke in the context of module '{0}' because it is not imported. Import the module '{0}' and try the operation again.
    ///  
    /// </summary>
    internal static string CantInvokeInNonImportedModule {
        get {
            return ResourceManager.GetString("CantInvokeInNonImportedModule", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Executable script code found in signature block.
    ///  
    /// </summary>
    internal static string TokenAfterEndOfValidScriptText {
        get {
            return ResourceManager.GetString("TokenAfterEndOfValidScriptText", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    line
    ///  
    /// </summary>
    internal static string TextForWordLine {
        get {
            return ResourceManager.GetString("TextForWordLine", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    At {0}:{1} char:{2}
    ///+ {3}
    ///  
    /// </summary>
    internal static string TextForPositionMessage {
        get {
            return ResourceManager.GetString("TextForPositionMessage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    {0,4}+ {1}
    ///  
    /// </summary>
    internal static string TraceScriptLineMessage {
        get {
            return ResourceManager.GetString("TraceScriptLineMessage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///        ! SET ${0} = '{1}'.
    ///  
    /// </summary>
    internal static string TraceVariableAssignment {
        get {
            return ResourceManager.GetString("TraceVariableAssignment", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///        ! CALL function '{0}'
    ///  
    /// </summary>
    internal static string TraceEnteringFunction {
        get {
            return ResourceManager.GetString("TraceEnteringFunction", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///        ! CALL function '{0}'  (defined in file '{1}')
    ///  
    /// </summary>
    internal static string TraceEnteringFunctionDefinedInFile {
        get {
            return ResourceManager.GetString("TraceEnteringFunctionDefinedInFile", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///        ! CALL method '{0}'
    ///  
    /// </summary>
    internal static string TraceMethodCall {
        get {
            return ResourceManager.GetString("TraceMethodCall", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The string is missing the terminator: {0}.
    ///  
    /// </summary>
    internal static string TerminatorExpectedAtEndOfString {
        get {
            return ResourceManager.GetString("TerminatorExpectedAtEndOfString", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    White space is not allowed before the string terminator.
    ///  
    /// </summary>
    internal static string WhitespaceBeforeHereStringFooter {
        get {
            return ResourceManager.GetString("WhitespaceBeforeHereStringFooter", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing ] at end of type token.
    ///  
    /// </summary>
    internal static string EndSquareBracketExpectedAtEndOfType {
        get {
            return ResourceManager.GetString("EndSquareBracketExpectedAtEndOfType", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Use `{ instead of { in variable names.
    ///  
    /// </summary>
    internal static string OpenBraceNeedsToBeBackTickedInVariableName {
        get {
            return ResourceManager.GetString("OpenBraceNeedsToBeBackTickedInVariableName", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The Data section is missing its statement block.
    ///  
    /// </summary>
    internal static string MissingStatementBlockForDataSection {
        get {
            return ResourceManager.GetString("MissingStatementBlockForDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The "{0}" parameter of the Data section is not valid. The valid Data section parameter is SupportedCommand.
    ///  
    /// </summary>
    internal static string InvalidParameterForDataSectionStatement {
        get {
            return ResourceManager.GetString("InvalidParameterForDataSectionStatement", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Array references are not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string ArrayReferenceNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("ArrayReferenceNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Assignment statements are not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string AssignmentStatementNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("AssignmentStatementNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Redirection is not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string RedirectionNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("RedirectionNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The Do and While statements are not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string DoWhileStatementNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("DoWhileStatementNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Expandable strings are not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string ExpandableStringNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("ExpandableStringNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The '{0}' operator is not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string OperatorNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("OperatorNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The Trap statement is not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string TrapStatementNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("TrapStatementNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The Try statement is not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string TryStatementNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("TryStatementNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Flow control statements such as Break, Continue, Return, Exit, and Throw are not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string FlowControlStatementNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("FlowControlStatementNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Foreach statements are not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string ForeachStatementNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("ForeachStatementNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    For and While statements are not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string ForWhileStatementNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("ForWhileStatementNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Function declarations are not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string FunctionDeclarationNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("FunctionDeclarationNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Method calls are not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string MethodCallNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("MethodCallNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Parameter declarations are not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string ParameterDeclarationNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("ParameterDeclarationNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Property references are not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string PropertyReferenceNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("PropertyReferenceNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Script block literals are not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string ScriptBlockNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("ScriptBlockNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The switch statement is not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string SwitchStatementNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("SwitchStatementNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A variable that cannot be referenced in restricted language mode or a Data section is being referenced. Variables that can be referenced include the following: {0}.
    ///  
    /// </summary>
    internal static string VariableReferenceNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("VariableReferenceNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The command '{0}' is not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string CmdletNotInAllowedListForDataSection {
        get {
            return ResourceManager.GetString("CmdletNotInAllowedListForDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The data statement is not allowed in restricted language mode or another Data section.
    ///  
    /// </summary>
    internal static string DataSectionStatementNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("DataSectionStatementNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The SupportedCommand parameter of the Data section is missing a value. Supply a cmdlet or function name to the parameter.
    ///  
    /// </summary>
    internal static string MissingValueForSupportedCommandInDataSectionStatement {
        get {
            return ResourceManager.GetString("MissingValueForSupportedCommandInDataSectionStatement", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A Begin statement block, Process statement block, or parameter statement is not allowed in a Data section.
    ///  
    /// </summary>
    internal static string InvalidScriptBlockInDataSection {
        get {
            return ResourceManager.GetString("InvalidScriptBlockInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    String multiplication results with more than "{0}" characters are not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string StringMultiplyToolongInDataSection {
        get {
            return ResourceManager.GetString("StringMultiplyToolongInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Array multiplication resulting in more than {0} elements is not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string ArrayMultiplyToolongInDataSection {
        get {
            return ResourceManager.GetString("ArrayMultiplyToolongInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Dot sourcing is not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string DotSourcingNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("DotSourcingNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Attribute argument must be a constant or a script block.
    ///  
    /// </summary>
    internal static string ParameterAttributeArgumentNeedsToBeConstantOrScriptBlock {
        get {
            return ResourceManager.GetString("ParameterAttributeArgumentNeedsToBeConstantOrScriptBlock", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot find the type for custom attribute '{0}'. Make sure that the assembly that contains this type is loaded.
    ///  
    /// </summary>
    internal static string CustomAttributeTypeNotFound {
        get {
            return ResourceManager.GetString("CustomAttributeTypeNotFound", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Property '{0}' cannot be found for type '{1}'.
    ///  
    /// </summary>
    internal static string PropertyNotFoundForType {
        get {
            return ResourceManager.GetString("PropertyNotFoundForType", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Unexpected attribute '{0}'.
    ///  
    /// </summary>
    internal static string UnexpectedAttribute {
        get {
            return ResourceManager.GetString("UnexpectedAttribute", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing ] at end of attribute or type literal.
    ///  
    /// </summary>
    internal static string EndSquareBracketExpectedAtEndOfAttribute {
        get {
            return ResourceManager.GetString("EndSquareBracketExpectedAtEndOfAttribute", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The function or command was called as if it were a method. Parameters should be separated by spaces. For information about parameters, see the about_Parameters Help topic.
    ///  
    /// </summary>
    internal static string StrictModeFunctionCallWithParens {
        get {
            return ResourceManager.GetString("StrictModeFunctionCallWithParens", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The Try statement is missing its statement block.
    ///  
    /// </summary>
    internal static string MissingTryStatementBlock {
        get {
            return ResourceManager.GetString("MissingTryStatementBlock", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The Try statement is missing its Catch or Finally block.
    ///  
    /// </summary>
    internal static string MissingCatchOrFinally {
        get {
            return ResourceManager.GetString("MissingCatchOrFinally", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The Catch block is missing its statement block.
    ///  
    /// </summary>
    internal static string MissingCatchHandlerBlock {
        get {
            return ResourceManager.GetString("MissingCatchHandlerBlock", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The Finally block is missing its statement block.
    ///  
    /// </summary>
    internal static string MissingFinallyStatementBlock {
        get {
            return ResourceManager.GetString("MissingFinallyStatementBlock", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Exception type {0} is already handled by a previous handler.
    ///  
    /// </summary>
    internal static string ExceptionTypeAlreadyCaught {
        get {
            return ResourceManager.GetString("ExceptionTypeAlreadyCaught", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Catch block must be the last catch block.
    ///  
    /// </summary>
    internal static string EmptyCatchNotLast {
        get {
            return ResourceManager.GetString("EmptyCatchNotLast", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing type literal.
    ///  
    /// </summary>
    internal static string MissingTypeLiteralToken {
        get {
            return ResourceManager.GetString("MissingTypeLiteralToken", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The terminator '#>' is missing from the multiline comment.
    ///  
    /// </summary>
    internal static string MissingTerminatorMultiLineComment {
        get {
            return ResourceManager.GetString("MissingTerminatorMultiLineComment", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    No characters are allowed after a here-string header but before the end of the line.
    ///  
    /// </summary>
    internal static string UnexpectedCharactersAfterHereStringHeader {
        get {
            return ResourceManager.GetString("UnexpectedCharactersAfterHereStringHeader", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Parser errors were detected.
    ///  
    /// </summary>
    internal static string ErrorCollection {
        get {
            return ResourceManager.GetString("ErrorCollection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing statement block after '{0}'.
    ///  
    /// </summary>
    internal static string MissingNamedStatementBlock {
        get {
            return ResourceManager.GetString("MissingNamedStatementBlock", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Unexpected type [{0}] was found in the parameter statement.
    ///  
    /// </summary>
    internal static string TypeNotAllowedBeforeParam {
        get {
            return ResourceManager.GetString("TypeNotAllowedBeforeParam", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Unexpected type [{0}] was found before statement.
    ///  
    /// </summary>
    internal static string TypeNotAllowedBeforeStatement {
        get {
            return ResourceManager.GetString("TypeNotAllowedBeforeStatement", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A null key is not allowed in a hash literal.
    ///  
    /// </summary>
    internal static string InvalidNullKey {
        get {
            return ResourceManager.GetString("InvalidNullKey", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Attributes are not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string AttributeNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("AttributeNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The type {0} is not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string TypeNotAllowedInDataSection {
        get {
            return ResourceManager.GetString("TypeNotAllowedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    '{0}' is a ReadOnly property.
    ///  
    /// </summary>
    internal static string PropertyIsReadOnly {
        get {
            return ResourceManager.GetString("PropertyIsReadOnly", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The type name is missing the assembly name specification.
    ///  
    /// </summary>
    internal static string MissingAssemblyNameSpecification {
        get {
            return ResourceManager.GetString("MissingAssemblyNameSpecification", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Flow of control cannot leave a Finally block.
    ///  
    /// </summary>
    internal static string ControlLeavingFinally {
        get {
            return ResourceManager.GetString("ControlLeavingFinally", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Unrecoverable error in PowerShell.
    ///  
    /// </summary>
    internal static string UnrecoverableParserError {
        get {
            return ResourceManager.GetString("UnrecoverableParserError", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    An AST cannot be used as the child of more than one AST. To use this AST in another AST, call the Copy() method and use its result.
    ///  
    /// </summary>
    internal static string AstIsReused {
        get {
            return ResourceManager.GetString("AstIsReused", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Expression is not allowed in a Using expression.
    ///  
    /// </summary>
    internal static string InvalidUsingExpression {
        get {
            return ResourceManager.GetString("InvalidUsingExpression", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A Using variable cannot be retrieved. A Using variable can be used only with Invoke-Command, Start-Job, or InlineScript in the script workflow. When it is used with Invoke-Command, the Using variable is valid only if the script block is invoked on a remote computer.
    ///  
    /// </summary>
    internal static string UsingWithoutInvokeCommand {
        get {
            return ResourceManager.GetString("UsingWithoutInvokeCommand", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Variable reference is not valid. The variable name is missing.
    ///  
    /// </summary>
    internal static string InvalidBracedVariableReference {
        get {
            return ResourceManager.GetString("InvalidBracedVariableReference", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Variable reference is not valid. ':' was not followed by a valid variable name character. Consider using ${} to delimit the name.
    ///  
    /// </summary>
    internal static string InvalidVariableReferenceWithDrive {
        get {
            return ResourceManager.GetString("InvalidVariableReferenceWithDrive", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Not all parse errors were reported.  Correct the reported errors and try again.
    ///  
    /// </summary>
    internal static string TooManyErrors {
        get {
            return ResourceManager.GetString("TooManyErrors", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing type name after '['.
    ///  
    /// </summary>
    internal static string MissingTypename {
        get {
            return ResourceManager.GetString("MissingTypename", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    * stream
    ///  
    /// </summary>
    internal static string AllStream {
        get {
            return ResourceManager.GetString("AllStream", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    debug stream
    ///  
    /// </summary>
    internal static string DebugStream {
        get {
            return ResourceManager.GetString("DebugStream", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    error stream
    ///  
    /// </summary>
    internal static string ErrorStream {
        get {
            return ResourceManager.GetString("ErrorStream", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    output stream
    ///  
    /// </summary>
    internal static string OutputStream {
        get {
            return ResourceManager.GetString("OutputStream", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The {0} for this command is already redirected.
    ///  
    /// </summary>
    internal static string StreamAlreadyRedirected {
        get {
            return ResourceManager.GetString("StreamAlreadyRedirected", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    verbose stream
    ///  
    /// </summary>
    internal static string VerboseStream {
        get {
            return ResourceManager.GetString("VerboseStream", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    warning stream
    ///  
    /// </summary>
    internal static string WarningStream {
        get {
            return ResourceManager.GetString("WarningStream", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing statement body after keyword '{0}'.
    ///  
    /// </summary>
    internal static string MissingStatementAfterKeyword {
        get {
            return ResourceManager.GetString("MissingStatementAfterKeyword", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Parallel and sequence blocks are not allowed in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string ParallelAndSequenceBlockNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("ParallelAndSequenceBlockNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Unexpected keyword '{0}'.
    ///  
    /// </summary>
    internal static string UnexpectedKeyword {
        get {
            return ResourceManager.GetString("UnexpectedKeyword", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    [void] cannot be used as a parameter type, or on the left side of an assignment.
    ///  
    /// </summary>
    internal static string VoidTypeConstraintNotAllowed {
        get {
            return ResourceManager.GetString("VoidTypeConstraintNotAllowed", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The method cannot be invoked.
    ///  
    /// </summary>
    internal static string CannotInvoke {
        get {
            return ResourceManager.GetString("CannotInvoke", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot convert hashtable to an object of the following type: {0}. Hashtable-to-Object conversion is not supported in restricted language mode or a Data section.
    ///  
    /// </summary>
    internal static string HashtableToObjectConversionNotSupportedInDataSection {
        get {
            return ResourceManager.GetString("HashtableToObjectConversionNotSupportedInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Argument must be constant.
    ///  
    /// </summary>
    internal static string RequiresArgumentMustBeConstant {
        get {
            return ResourceManager.GetString("RequiresArgumentMustBeConstant", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The argument for the {0} parameter is not valid. Specify a valid string argument.
    ///  
    /// </summary>
    internal static string RequiresInvalidStringArgument {
        get {
            return ResourceManager.GetString("RequiresInvalidStringArgument", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The argument for the Module parameter is not valid. {0}
    ///  
    /// </summary>
    internal static string RequiresModuleInvalid {
        get {
            return ResourceManager.GetString("RequiresModuleInvalid", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The argument for the Version parameter is not valid. Specify a valid PowerShell version, in the format major.minor version.
    ///  
    /// </summary>
    internal static string RequiresVersionInvalid {
        get {
            return ResourceManager.GetString("RequiresVersionInvalid", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The argument for the {0} parameter is not valid. Specify a valid PowerShell edition.
    ///  
    /// </summary>
    internal static string RequiresPSEditionInvalid {
        get {
            return ResourceManager.GetString("RequiresPSEditionInvalid", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The argument for the {0} parameter contains duplicate values. Do not specify duplicate PowerShell edition values.
    ///  
    /// </summary>
    internal static string RequiresPSEditionValueIsAlreadySpecified {
        get {
            return ResourceManager.GetString("RequiresPSEditionValueIsAlreadySpecified", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Wildcard characters are not supported for module names.
    ///  
    /// </summary>
    internal static string WildCardModuleNameError {
        get {
            return ResourceManager.GetString("WildCardModuleNameError", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot invoke method. Method invocation is supported only on core types in this language mode.
    ///  
    /// </summary>
    internal static string InvokeMethodConstrainedLanguage {
        get {
            return ResourceManager.GetString("InvokeMethodConstrainedLanguage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot set property. Property setting is supported only on core types in this language mode.
    ///  
    /// </summary>
    internal static string PropertySetConstrainedLanguage {
        get {
            return ResourceManager.GetString("PropertySetConstrainedLanguage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    An attribute name for resource '{0}' was found that is not valid. An attribute name must be a simple string, and cannot contain variables or expressions. Replace '{1}' with a simple string.
    ///  
    /// </summary>
    internal static string ConfigurationInvalidPropertyName {
        get {
            return ResourceManager.GetString("ConfigurationInvalidPropertyName", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The member '{0}' is not valid. Valid members are
    ///'{1}'.
    ///  
    /// </summary>
    internal static string InvalidInstanceProperty {
        get {
            return ResourceManager.GetString("InvalidInstanceProperty", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing '{' in object definition.
    ///  
    /// </summary>
    internal static string MissingBraceInObjectDefinition {
        get {
            return ResourceManager.GetString("MissingBraceInObjectDefinition", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A required name or expression was missing.
    ///  
    /// </summary>
    internal static string RequiredNameOrExpressionMissing {
        get {
            return ResourceManager.GetString("RequiredNameOrExpressionMissing", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The schema file {0} was not found. Verify that any modules specified in a configuration statement contain a schema.mof file, and then try running the script again.
    ///  
    /// </summary>
    internal static string SchemaFileNotFound {
        get {
            return ResourceManager.GetString("SchemaFileNotFound", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot define data section. Definition of additional supported commands is not supported in this language mode.
    ///  
    /// </summary>
    internal static string DataSectionAllowedCommandDisallowed {
        get {
            return ResourceManager.GetString("DataSectionAllowedCommandDisallowed", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing '{' in configuration statement.
    ///  
    /// </summary>
    internal static string MissingCurlyInConfigurationStatement {
        get {
            return ResourceManager.GetString("MissingCurlyInConfigurationStatement", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Exception parsing MOF file '{0}':{1}.
    ///  
    /// </summary>
    internal static string ExceptionParsingMOFFile {
        get {
            return ResourceManager.GetString("ExceptionParsingMOFFile", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The name for the configuration is missing. Provide the missing name as a simple name, string, or string-valued expression.
    ///  
    /// </summary>
    internal static string MissingConfigurationName {
        get {
            return ResourceManager.GetString("MissingConfigurationName", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Could not find the module '{0}'.
    ///  
    /// </summary>
    internal static string ModuleNotFoundDuringParse {
        get {
            return ResourceManager.GetString("ModuleNotFoundDuringParse", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Multiple versions of the module '{0}' were found. You can run 'Get-Module -ListAvailable -FullyQualifiedName {0}' to see available versions on the system, and then use the fully qualified name '@{{ModuleName="{0}"; RequiredVersion="Version"}}'.
    ///  
    /// </summary>
    internal static string MultipleModuleEntriesFoundDuringParse {
        get {
            return ResourceManager.GetString("MultipleModuleEntriesFoundDuringParse", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The ThrottleLimit parameter of the foreach statement is missing a value. Supply a throttle limit to the parameter.
    ///    'ThrottleLimit' must not be localized.
    ///  
    /// </summary>
    internal static string MissingThrottleLimit {
        get {
            return ResourceManager.GetString("MissingThrottleLimit", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The ThrottleLimit parameter is only supported on foreach statements that use the Parallel parameter.
    ///    'ThrottleLimit' and 'Parallel' must not be localized.
    ///  
    /// </summary>
    internal static string ThrottleLimitRequiresParallelFlag {
        get {
            return ResourceManager.GetString("ThrottleLimitRequiresParallelFlag", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The configuration block results were null or empty. Verify that configurations were defined in the block.
    ///  
    /// </summary>
    internal static string ConfigurationBodyEmpty {
        get {
            return ResourceManager.GetString("ConfigurationBodyEmpty", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The '{0}' resource can only be used once per configuration, and therefore cannot have a name. Remove '{1}', and then run the script again.
    ///  
    /// </summary>
    internal static string UnexpectedNameForType {
        get {
            return ResourceManager.GetString("UnexpectedNameForType", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    There is an incomplete property assignment block in the instance definition.
    ///  
    /// </summary>
    internal static string IncompletePropertyAssignmentBlock {
        get {
            return ResourceManager.GetString("IncompletePropertyAssignmentBlock", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing '=' operator after key in property assignment.
    ///  
    /// </summary>
    internal static string MissingEqualsInPropertyAssignmentBlock {
        get {
            return ResourceManager.GetString("MissingEqualsInPropertyAssignmentBlock", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Duplicate property assignments are not allowed in an instance definition.
    ///  
    /// </summary>
    internal static string DuplicatePropertyInInstanceDefinition {
        get {
            return ResourceManager.GetString("DuplicatePropertyInInstanceDefinition", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A second CIM class definition for '{0}' was found while processing the schema file '{1}'. This class was already defined in the file(s) '{2}'. Remove the redundant definition, and then try again.
    ///  
    /// </summary>
    internal static string DuplicateCimClassDefinition {
        get {
            return ResourceManager.GetString("DuplicateCimClassDefinition", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Resource name '{0}' is already being used by another Resource or Configuration.
    ///  
    /// </summary>
    internal static string DuplicateKeywordDefinition {
        get {
            return ResourceManager.GetString("DuplicateKeywordDefinition", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The class name '{0}' does not match '{1}', the name of the file in which it is defined. Rename either the file name to match the class name or vice versa
    ///  
    /// </summary>
    internal static string ClassNameNotSameAsDefiningFile {
        get {
            return ResourceManager.GetString("ClassNameNotSameAsDefiningFile", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A duplicate resource identifier '{0}' was found while processing the specification for node '{1}'. Change the name of this resource so that it is unique within the node specification.
    ///  
    /// </summary>
    internal static string DuplicateResourceIdInNodeStatement {
        get {
            return ResourceManager.GetString("DuplicateResourceIdInNodeStatement", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    There is no whitespace between the name and the scriptblock in dynamic keyword '{0}' body statement.
    ///  
    /// </summary>
    internal static string UnexpectedTokenInDynamicKeyword {
        get {
            return ResourceManager.GetString("UnexpectedTokenInDynamicKeyword", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The key property for an entry in the dictionary of functions to define cannot be empty because the key property is used as the function name. Specify a non-empty string as the value of the key property, and then try the operation again.
    ///  
    /// </summary>
    internal static string EmptyFunctionNameInFunctionDefinitionDictionary {
        get {
            return ResourceManager.GetString("EmptyFunctionNameInFunctionDefinitionDictionary", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The format of the resource reference '{0}' in the Requires list for resource '{1}' is not valid. A required resource name should be in the format '[<typename>]<name>', with alphanumeric characters, spaces, '_', '-', '.' and '\'.
    ///    The capitalized word Requires should not be localized. The words <typename> and <name> should be localized but the <> characters must be preserved.
    ///  
    /// </summary>
    internal static string GetBadlyFormedRequiredResourceId {
        get {
            return ResourceManager.GetString("GetBadlyFormedRequiredResourceId", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The format of the resource reference '{0}' in the exclusive list for resource '{1}' is not valid. An exclusive resource name should be in the format '<typename>\<name>', with no spaces.
    ///  
    /// </summary>
    internal static string GetBadlyFormedExclusiveResourceId {
        get {
            return ResourceManager.GetString("GetBadlyFormedExclusiveResourceId", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The PartialConfiguration '{0}' is set to pull mode which requires a ConfigurationSource property.
    ///  
    /// </summary>
    internal static string GetPullModeNeedConfigurationSource {
        get {
            return ResourceManager.GetString("GetPullModeNeedConfigurationSource", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A null entry was found in the list of variable entries to create in the script block scope. Remove the entry at index {0}, or replace it with a non-null entry, and then try again.
    ///  
    /// </summary>
    internal static string NullEntryInVariablesDefinitionList {
        get {
            return ResourceManager.GetString("NullEntryInVariablesDefinitionList", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The script block that defines function '{0}' cannot be null or empty. Provide a non-empty script block in the function definition dictionary, and then try the operation again.
    ///  
    /// </summary>
    internal static string NullFunctionBodyInFunctionDefinitionDictionary {
        get {
            return ResourceManager.GetString("NullFunctionBodyInFunctionDefinitionDictionary", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The syntax of the Import-DscResource dynamic keyword is:
    ///
    ///Import-DscResource  [-Name <ResourceName(s)>]  [-ModuleName  <ModuleName(s)>] [-ModuleVersion <ModuleVersion>].
    ///
    ///Name          : Names of one or more resources to import.
    ///ModuleName    : Module names or ModuleSpecification objects of one or more modules to import.
    ///ModuleVersion : Version of module to import. If used, ModuleName must represent only one module by name.
    ///  
    /// </summary>
    internal static string ImportDscResourceNeedParams {
        get {
            return ResourceManager.GetString("ImportDscResourceNeedParams", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Import-DscResource dynamic keyword supports only one module when Name parameter is specified.
    ///  
    /// </summary>
    internal static string ImportDscResourceMultipleModulesNotSupportedWithName {
        get {
            return ResourceManager.GetString("ImportDscResourceMultipleModulesNotSupportedWithName", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Positional parameters are not supported for the Import-DscResource dynamic keyword. The syntax of Import-DscResource dynamic keyword is: "Import-DscResource  [-Name <ResourceName(s)>] [-ModuleName <ModuleName(s)>] [-ModuleVersion <ModuleVersion>]
    ///  
    /// </summary>
    internal static string ImportDscResourcePositionalParamsNotSupported {
        get {
            return ResourceManager.GetString("ImportDscResourcePositionalParamsNotSupported", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Unable to load resource '{0}': Resource not found.
    ///  
    /// </summary>
    internal static string DscResourcesNotFoundDuringParsing {
        get {
            return ResourceManager.GetString("DscResourcesNotFoundDuringParsing", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Configuration keyword is not allowed in constrainedLanguage mode.
    ///  
    /// </summary>
    internal static string ConfigurationNotAllowedInConstrainedLanguage {
        get {
            return ResourceManager.GetString("ConfigurationNotAllowedInConstrainedLanguage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The configuration name '{0}' is not valid. Standard names may only contain letters (a-z, A-Z), numbers (0-9), period (.), hyphen (-) and underscore (_). The name may not be null or empty, and should start with a letter.
    ///  
    /// </summary>
    internal static string InvalidConfigurationName {
        get {
            return ResourceManager.GetString("InvalidConfigurationName", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Configuration only supports the End block in its body. Begin, Process and DynamicParam blocks are not allowed in a configuration.
    ///  
    /// </summary>
    internal static string UnsupportedNamedBlockInConfiguration {
        get {
            return ResourceManager.GetString("UnsupportedNamedBlockInConfiguration", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cim deserializer threw an error when deserializing file {0}.
    ///  
    /// </summary>
    internal static string CimDeserializationError {
        get {
            return ResourceManager.GetString("CimDeserializationError", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    '{0}' is not a valid value for property '{1}' on class '{2}'. Please change the value to one of the following strings: {3}.
    ///  
    /// </summary>
    internal static string InvalidValueForProperty {
        get {
            return ResourceManager.GetString("InvalidValueForProperty", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    At least one of the values '{0}' is not supported or valid for property '{1}' on class '{2}'. Please specify only supported values:
    ///{3}.
    ///  
    /// </summary>
    internal static string UnsupportedValueForProperty {
        get {
            return ResourceManager.GetString("UnsupportedValueForProperty", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Resource '{0}' requires that a value of type '{1}' be provided for property '{2}'.
    ///  
    /// </summary>
    internal static string MissingValueForMandatoryProperty {
        get {
            return ResourceManager.GetString("MissingValueForMandatoryProperty", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Property '{0}' of Resource '{1}' has value '{2}' which is not between valid range '{3}' and '{4}'.
    ///  
    /// </summary>
    internal static string ValueNotInRange {
        get {
            return ResourceManager.GetString("ValueNotInRange", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Failed to load the PowerShell data file '{0}' with the following error:
    ///{1}
    ///  
    /// </summary>
    internal static string CannotLoadPowerShellDataFile {
        get {
            return ResourceManager.GetString("CannotLoadPowerShellDataFile", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot resolve the path '{0}' to a single .psd1 file.
    ///  
    /// </summary>
    internal static string CannotResolvePowerShellDataFilePath {
        get {
            return ResourceManager.GetString("CannotResolvePowerShellDataFilePath", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The PowerShell data file '{0}' is invalid since it cannot be evaluated into a Hashtable object.
    ///  
    /// </summary>
    internal static string InvalidPowerShellDataFile {
        get {
            return ResourceManager.GetString("InvalidPowerShellDataFile", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Configuration is not supported on WinPE.
    ///  
    /// </summary>
    internal static string ConfigurationNotAllowedOnWinPE {
        get {
            return ResourceManager.GetString("ConfigurationNotAllowedOnWinPE", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    If the expression passed to the Where() operator is null then you must specify a non-Default value for the selection mode argument. Please change the value of the mode argument to a value other than Default and try running your script again.
    ///  
    /// </summary>
    internal static string EmptyExpressionRequiresANonDefaultMode {
        get {
            return ResourceManager.GetString("EmptyExpressionRequiresANonDefaultMode", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The generic collection type [{0}] passed to ForEach() has too many type arguments. Please change the specified type to be a generic collection with only one type argument then try running your script again.
    ///  
    /// </summary>
    internal static string ForEachBadGenericConversionTypeSpecified {
        get {
            return ResourceManager.GetString("ForEachBadGenericConversionTypeSpecified", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Unable to convert input to the target type [{0}] passed to the ForEach() operator. Please check the specified type and try running your script again.
    ///  
    /// </summary>
    internal static string ForEachTypeConversionFailed {
        get {
            return ResourceManager.GetString("ForEachTypeConversionFailed", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Script block with a 'clean' block is not supported by the 'ForEach' method.
    ///  
    /// </summary>
    internal static string ForEachNotSupportCleanBlock {
        get {
            return ResourceManager.GetString("ForEachNotSupportCleanBlock", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The 'numberToReturn' value provided to the third argument of the Where() operator must be greater than zero. Please correct the argument's value and try running your script again.
    ///  
    /// </summary>
    internal static string NumberToReturnMustBeGreaterThanZero {
        get {
            return ResourceManager.GetString("NumberToReturnMustBeGreaterThanZero", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Redirection only allows another stream to be merged with the output stream. Please correct the redirection operation to merge into the output stream then try running your script again.
    ///  
    /// </summary>
    internal static string RedirectionStreamCanOnlyMergeToOutputStream {
        get {
            return ResourceManager.GetString("RedirectionStreamCanOnlyMergeToOutputStream", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The ForEach() operator could not find a member '{0}' on the target object. Please verify that the named member exists and then try running your script again.
    ///  
    /// </summary>
    internal static string ForEachNonexistentMemberReference {
        get {
            return ResourceManager.GetString("ForEachNonexistentMemberReference", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The '{0}' keyword is not supported in this version of the language.
    ///  
    /// </summary>
    internal static string UnsupportedReservedKeyword {
        get {
            return ResourceManager.GetString("UnsupportedReservedKeyword", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The '{0}' property is not supported in this version of the language.
    ///  
    /// </summary>
    internal static string UnsupportedReservedProperty {
        get {
            return ResourceManager.GetString("UnsupportedReservedProperty", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Duplicate '{0}' qualifier
    ///  
    /// </summary>
    internal static string DuplicateQualifier {
        get {
            return ResourceManager.GetString("DuplicateQualifier", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Modifier '{0}' cannot be combined with '{1}'
    ///  
    /// </summary>
    internal static string ModifiersCannotBeCombined {
        get {
            return ResourceManager.GetString("ModifiersCannotBeCombined", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing using directive
    ///  
    /// </summary>
    internal static string MissingUsingStatementDirective {
        get {
            return ResourceManager.GetString("MissingUsingStatementDirective", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing namespace alias
    ///  
    /// </summary>
    internal static string MissingNamespaceAlias {
        get {
            return ResourceManager.GetString("MissingNamespaceAlias", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing '=' operator
    ///  
    /// </summary>
    internal static string MissingEqualsInUsingAlias {
        get {
            return ResourceManager.GetString("MissingEqualsInUsingAlias", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing using name
    ///  
    /// </summary>
    internal static string MissingUsingItemName {
        get {
            return ResourceManager.GetString("MissingUsingItemName", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Variable is not assigned in the method.
    ///  
    /// </summary>
    internal static string VariableNotLocal {
        get {
            return ResourceManager.GetString("VariableNotLocal", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing a property name or method definition.
    ///  
    /// </summary>
    internal static string IncompleteMemberDefinition {
        get {
            return ResourceManager.GetString("IncompleteMemberDefinition", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The member '{0}' is already defined.
    ///  
    /// </summary>
    internal static string MemberAlreadyDefined {
        get {
            return ResourceManager.GetString("MemberAlreadyDefined", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Only one type may be specified on class members.
    ///  
    /// </summary>
    internal static string TooManyTypes {
        get {
            return ResourceManager.GetString("TooManyTypes", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Error during creation of type "{0}". Error message:
    ///{1}
    ///  
    /// </summary>
    internal static string TypeCreationError {
        get {
            return ResourceManager.GetString("TypeCreationError", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot convert the value to type "{0}".
    ///  
    /// </summary>
    internal static string CannotConvertValue {
        get {
            return ResourceManager.GetString("CannotConvertValue", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Property '{0}' cannot be found for attribute '{1}'. Specify one of the following properties: {2}.
    ///  
    /// </summary>
    internal static string PropertyNotFoundForAttribute {
        get {
            return ResourceManager.GetString("PropertyNotFoundForAttribute", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Attribute '{0}' is not valid on this declaration. It is valid on '{1}' declarations only.
    ///  
    /// </summary>
    internal static string AttributeNotAllowedOnDeclaration {
        get {
            return ResourceManager.GetString("AttributeNotAllowedOnDeclaration", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Attribute argument must be a constant.
    ///  
    /// </summary>
    internal static string ParameterAttributeArgumentNeedsToBeConstant {
        get {
            return ResourceManager.GetString("ParameterAttributeArgumentNeedsToBeConstant", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Undefined DSC resource '{0}'. Use Import-DSCResource to import the resource.
    ///  
    /// </summary>
    internal static string ResourceNotDefined {
        get {
            return ResourceManager.GetString("ResourceNotDefined", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Exception occurred when pre-parsing dynamic keyword '{0}' with details '{1}'.
    ///  
    /// </summary>
    internal static string DynamicKeywordPreParseException {
        get {
            return ResourceManager.GetString("DynamicKeywordPreParseException", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Exception occurred when post-parsing dynamic keyword '{0}' with details '{1}'.
    ///  
    /// </summary>
    internal static string DynamicKeywordPostParseException {
        get {
            return ResourceManager.GetString("DynamicKeywordPostParseException", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Workflow is not supported in PowerShell 6+.
    ///  
    /// </summary>
    internal static string WorkflowNotSupportedInPowerShellCore {
        get {
            return ResourceManager.GetString("WorkflowNotSupportedInPowerShellCore", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Meta Configuration resource {0} is not allowed in the regular configuration. Use meta configuration resources in a configuration with [DscLocalConfigurationManager()] attribute.
    ///  
    /// </summary>
    internal static string MetaConfigurationUsedInRegularConfig {
        get {
            return ResourceManager.GetString("MetaConfigurationUsedInRegularConfig", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Regular DSC resource {0} is not allowed in the meta configuration. 
    ///  
    /// </summary>
    internal static string RegularResourceUsedInMetaConfig {
        get {
            return ResourceManager.GetString("RegularResourceUsedInMetaConfig", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    There is no Runspace available to get and run the SteppablePipeline in this thread. You can provide one in the DefaultRunspace property of the System.Management.Automation.Runspaces.Runspace type. The script block you attempted to get SteppablePipeline from was: {0}
    ///  
    /// </summary>
    internal static string GetSteppablePipelineFromWrongThread {
        get {
            return ResourceManager.GetString("GetSteppablePipelineFromWrongThread", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    There are valid conversions from {0} to {1}.
    ///  
    /// </summary>
    internal static string AmbiguousConversion {
        get {
            return ResourceManager.GetString("AmbiguousConversion", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot perform call.
    ///  
    /// </summary>
    internal static string CannotCall {
        get {
            return ResourceManager.GetString("CannotCall", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot retrieve type information.
    ///  
    /// </summary>
    internal static string CannotRetrieveTypeInformation {
        get {
            return ResourceManager.GetString("CannotRetrieveTypeInformation", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Could not get dispatch ID for {0} (error: {1}).
    ///  
    /// </summary>
    internal static string CouldNotGetDispId {
        get {
            return ResourceManager.GetString("CouldNotGetDispId", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot find an overload for "{0}" and the argument count: "{1}"
    ///  
    /// </summary>
    internal static string DispBadParamCount {
        get {
            return ResourceManager.GetString("DispBadParamCount", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Error while invoking {0}. Could not find member.
    ///  
    /// </summary>
    internal static string DispMemberNotFound {
        get {
            return ResourceManager.GetString("DispMemberNotFound", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Error while invoking {0}. Named arguments are not supported.
    ///  
    /// </summary>
    internal static string DispNoNamedArgs {
        get {
            return ResourceManager.GetString("DispNoNamedArgs", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Error while invoking {0}. Overflow detected.
    ///  
    /// </summary>
    internal static string DispOverflow {
        get {
            return ResourceManager.GetString("DispOverflow", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Error while invoking {0}. A required parameter was omitted.
    ///  
    /// </summary>
    internal static string DispParamNotOptional {
        get {
            return ResourceManager.GetString("DispParamNotOptional", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Exception setting "{0}": Cannot convert the "{1}" value of type "{2}" to type "{3}".
    ///  
    /// </summary>
    internal static string DispTypeMismatch {
        get {
            return ResourceManager.GetString("DispTypeMismatch", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    IDispatch::GetIDsOfNames behaved unexpectedly for {0}.
    ///  
    /// </summary>
    internal static string GetIDsOfNamesInvalid {
        get {
            return ResourceManager.GetString("GetIDsOfNamesInvalid", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Marshal.SetComObjectData failed.
    ///  
    /// </summary>
    internal static string SetComObjectDataFailed {
        get {
            return ResourceManager.GetString("SetComObjectDataFailed", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Unexpected VarEnum {0}.
    ///  
    /// </summary>
    internal static string UnexpectedVarEnum {
        get {
            return ResourceManager.GetString("UnexpectedVarEnum", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Attempting to pass an event handler of an unsupported type.
    ///  
    /// </summary>
    internal static string UnsupportedHandlerType {
        get {
            return ResourceManager.GetString("UnsupportedHandlerType", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Configuration keyword is not supported in PowerShell 6+.
    ///  
    /// </summary>
    internal static string ConfigurationNotSupportedInPowerShellCore {
        get {
            return ResourceManager.GetString("ConfigurationNotSupportedInPowerShellCore", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Not all code path returns value within method.
    ///  
    /// </summary>
    internal static string MethodHasCodePathNotReturn {
        get {
            return ResourceManager.GetString("MethodHasCodePathNotReturn", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Invalid return statement within void method.
    ///  
    /// </summary>
    internal static string VoidMethodHasReturn {
        get {
            return ResourceManager.GetString("VoidMethodHasReturn", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Invalid return statement within non-void method.
    ///  
    /// </summary>
    internal static string NonVoidMethodMissingReturnValue {
        get {
            return ResourceManager.GetString("NonVoidMethodMissingReturnValue", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing '{0}' body in '{0}' declaration.
    ///  
    /// </summary>
    internal static string MissingTypeBody {
        get {
            return ResourceManager.GetString("MissingTypeBody", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot define enum because of a cycle in the initialization expressions.
    ///  
    /// </summary>
    internal static string CycleInEnumInitializers {
        get {
            return ResourceManager.GetString("CycleInEnumInitializers", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Enumerator value is either too large or too small for {0}.
    ///  
    /// </summary>
    internal static string EnumeratorValueOutOfBounds {
        get {
            return ResourceManager.GetString("EnumeratorValueOutOfBounds", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Enumerator value must be a constant value.
    ///  
    /// </summary>
    internal static string EnumeratorValueMustBeConstant {
        get {
            return ResourceManager.GetString("EnumeratorValueMustBeConstant", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Exception occurred when performing semantic check for dynamic keyword '{0}' with details '{1}'.
    ///  
    /// </summary>
    internal static string DynamicKeywordSemanticCheckException {
        get {
            return ResourceManager.GetString("DynamicKeywordSemanticCheckException", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The '{0}' property with type '{1}' of DSC resource class '{2}' is not supported.
    ///  
    /// </summary>
    internal static string UnsupportedPropertyTypeOfDSCResourceClass {
        get {
            return ResourceManager.GetString("UnsupportedPropertyTypeOfDSCResourceClass", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing '(' in class method parameter list.
    ///  
    /// </summary>
    internal static string MissingMethodParameterList {
        get {
            return ResourceManager.GetString("MissingMethodParameterList", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A named block is not allowed in a class method.
    ///  
    /// </summary>
    internal static string NamedBlockNotAllowedInMethod {
        get {
            return ResourceManager.GetString("NamedBlockNotAllowedInMethod", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A param block is not allowed in a class method.
    ///  
    /// </summary>
    internal static string ParamBlockNotAllowedInMethod {
        get {
            return ResourceManager.GetString("ParamBlockNotAllowedInMethod", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot inherit from sealed class '{0}'.
    ///  
    /// </summary>
    internal static string SealedBaseClass {
        get {
            return ResourceManager.GetString("SealedBaseClass", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Type name expected.
    ///  
    /// </summary>
    internal static string TypeNameExpected {
        get {
            return ResourceManager.GetString("TypeNameExpected", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    '{0}' is not a valid underlying type for enums. Expected a builtin integral type (one of byte, sbyte, short, ushort, int, uint, long or ulong)
    ///  
    /// </summary>
    internal static string InvalidUnderlyingType {
        get {
            return ResourceManager.GetString("InvalidUnderlyingType", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    '{0}': Interface name expected.
    ///  
    /// </summary>
    internal static string InterfaceNameExpected {
        get {
            return ResourceManager.GetString("InterfaceNameExpected", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Base class '{0}' does not contain a parameterless constructor.
    ///  
    /// </summary>
    internal static string BaseClassNoDefaultCtor {
        get {
            return ResourceManager.GetString("BaseClassNoDefaultCtor", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Invalid base type '{0}'. Base type cannot be an array.
    ///  
    /// </summary>
    internal static string SubtypeArray {
        get {
            return ResourceManager.GetString("SubtypeArray", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Invalid base type '{0}'. Base type cannot be a generic with unspecified parameters.
    ///  
    /// </summary>
    internal static string SubtypeUnclosedGeneric {
        get {
            return ResourceManager.GetString("SubtypeUnclosedGeneric", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing 'base' after ':' in a base class constructor call.
    ///  
    /// </summary>
    internal static string MissingBaseCtorCall {
        get {
            return ResourceManager.GetString("MissingBaseCtorCall", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A constructor cannot specify a return type.
    ///  
    /// </summary>
    internal static string ConstructorCantHaveReturnType {
        get {
            return ResourceManager.GetString("ConstructorCantHaveReturnType", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The DSC resource '{0}' has no default constructor.
    ///  
    /// </summary>
    internal static string DscResourceMissingDefaultConstructor {
        get {
            return ResourceManager.GetString("DscResourceMissingDefaultConstructor", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The DSC resource '{0}' is missing a Get method that returns [{0}] and accepts no parameters.
    ///  
    /// </summary>
    internal static string DscResourceMissingGetMethod {
        get {
            return ResourceManager.GetString("DscResourceMissingGetMethod", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The DSC resource '{0}' must have at least one key property (using the syntax [DscProperty(Key)].)
    ///  
    /// </summary>
    internal static string DscResourceMissingKeyProperty {
        get {
            return ResourceManager.GetString("DscResourceMissingKeyProperty", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The DSC resource '{0}' is missing a Set method that returns [void] and accepts no parameters.
    ///  
    /// </summary>
    internal static string DscResourceMissingSetMethod {
        get {
            return ResourceManager.GetString("DscResourceMissingSetMethod", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The DSC resource '{0}' is missing a Test method that returns [bool] and accepts no parameters.
    ///  
    /// </summary>
    internal static string DscResourceMissingTestMethod {
        get {
            return ResourceManager.GetString("DscResourceMissingTestMethod", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A static constructor cannot have any parameters.
    ///  
    /// </summary>
    internal static string StaticConstructorCantHaveParameters {
        get {
            return ResourceManager.GetString("StaticConstructorCantHaveParameters", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The type '{0}' is not allowed on a property.
    ///  
    /// </summary>
    internal static string TypeNotAllowedForProperty {
        get {
            return ResourceManager.GetString("TypeNotAllowedForProperty", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The type '{0}' is not allowed on a parameter.
    ///  
    /// </summary>
    internal static string TypeNotAllowedForParameter {
        get {
            return ResourceManager.GetString("TypeNotAllowedForParameter", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot access the non-static member '{0}' in a static method or initializer of a static property.
    ///  
    /// </summary>
    internal static string NonStaticMemberAccessInStaticMember {
        get {
            return ResourceManager.GetString("NonStaticMemberAccessInStaticMember", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Failed to parse module script file '{0}' with error
    ///'{1}'.
    ///  
    /// </summary>
    internal static string FailToParseModuleScriptFile {
        get {
            return ResourceManager.GetString("FailToParseModuleScriptFile", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot run a document in PowerShell: {0}.
    ///  
    /// </summary>
    internal static string CantActivateDocumentInPowerShellCore {
        get {
            return ResourceManager.GetString("CantActivateDocumentInPowerShellCore", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Multiple type constraints are not allowed on a method parameter.
    ///  
    /// </summary>
    internal static string MultipleTypeConstraintsOnMethodParam {
        get {
            return ResourceManager.GetString("MultipleTypeConstraintsOnMethodParam", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    This script contains malicious content and has been blocked by your antivirus software.
    ///  
    /// </summary>
    internal static string ScriptContainedMaliciousContent {
        get {
            return ResourceManager.GetString("ScriptContainedMaliciousContent", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    '{0}' cannot be specified in LocalConfigurationManager resource. Please switch to Settings instead or use only following values: {1}.
    ///  
    /// </summary>
    internal static string InvalidLocalConfigurationManagerProperty {
        get {
            return ResourceManager.GetString("InvalidLocalConfigurationManagerProperty", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    '{0}' is defined in a generic type.
    ///  
    /// </summary>
    internal static string PropertyInGenericType {
        get {
            return ResourceManager.GetString("PropertyInGenericType", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Type name '{0}' is ambiguous, it could be '{1}' or '{2}'.
    ///  
    /// </summary>
    internal static string AmbiguousTypeReference {
        get {
            return ResourceManager.GetString("AmbiguousTypeReference", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A 'using' statement must appear before any other statements in a script.
    ///  
    /// </summary>
    internal static string UsingMustBeAtStartOfScript {
        get {
            return ResourceManager.GetString("UsingMustBeAtStartOfScript", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    This syntax of the 'using' statement is not supported.
    ///  
    /// </summary>
    internal static string UsingStatementNotSupported {
        get {
            return ResourceManager.GetString("UsingStatementNotSupported", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The specified namespace in the 'using' statement contains invalid characters.
    ///  
    /// </summary>
    internal static string InvalidNamespaceValue {
        get {
            return ResourceManager.GetString("InvalidNamespaceValue", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    information stream
    ///  
    /// </summary>
    internal static string InformationStream {
        get {
            return ResourceManager.GetString("InformationStream", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Invalid key property. The key property must be of [string], signed/unsigned integer, or Enum types.
    ///  
    /// </summary>
    internal static string DscResourceInvalidKeyProperty {
        get {
            return ResourceManager.GetString("DscResourceInvalidKeyProperty", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Invalid Get method. Get method must return [{0}] and accepts no parameters.
    ///  
    /// </summary>
    internal static string DscResourceInvalidGetMethod {
        get {
            return ResourceManager.GetString("DscResourceInvalidGetMethod", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot load assembly '{0}'.
    ///  
    /// </summary>
    internal static string ErrorLoadingAssembly {
        get {
            return ResourceManager.GetString("ErrorLoadingAssembly", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot use assembly with an UNC path: '{0}'.
    ///  
    /// </summary>
    internal static string CannotLoadAssemblyFromUncPath {
        get {
            return ResourceManager.GetString("CannotLoadAssemblyFromUncPath", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot use assembly with uri schema '{0}'.
    ///  
    /// </summary>
    internal static string CannotLoadAssemblyWithUriSchema {
        get {
            return ResourceManager.GetString("CannotLoadAssemblyWithUriSchema", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing a newline or semicolon.
    ///  
    /// </summary>
    internal static string MissingStatementTerminator {
        get {
            return ResourceManager.GetString("MissingStatementTerminator", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot assign property, use '{0}{1}'.
    ///  
    /// </summary>
    internal static string MissingThis {
        get {
            return ResourceManager.GetString("MissingThis", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    '{0}' is not a valid value for using name.
    ///  
    /// </summary>
    internal static string InvalidValueForUsingItemName {
        get {
            return ResourceManager.GetString("InvalidValueForUsingItemName", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot assign property, use '{0}{1}'.
    ///  
    /// </summary>
    internal static string MissingTypeInStaticPropertyAssignment {
        get {
            return ResourceManager.GetString("MissingTypeInStaticPropertyAssignment", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    DebugMode should only have one value.
    ///  
    /// </summary>
    internal static string DebugModeShouldHaveOneValue {
        get {
            return ResourceManager.GetString("DebugModeShouldHaveOneValue", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Label '{0}' not found inside the method.
    ///  
    /// </summary>
    internal static string LabelNotFound {
        get {
            return ResourceManager.GetString("LabelNotFound", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Failed to convert the value of CimProperty {0} to the property value of class {1}.
    ///  
    /// </summary>
    internal static string ConvertCimPropertyToObjectPropertyFailed {
        get {
            return ResourceManager.GetString("ConvertCimPropertyToObjectPropertyFailed", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Property {0} of PowerShell class {1} is not declared as array type, but defined in its configuration instance as instance array type.
    ///  
    /// </summary>
    internal static string ExpectArrayTypeOfPropertyInPSClass {
        get {
            return ResourceManager.GetString("ExpectArrayTypeOfPropertyInPSClass", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Failed to create an object of PowerShell class {0}.
    ///  
    /// </summary>
    internal static string InstantiatePSClassObjectFailed {
        get {
            return ResourceManager.GetString("InstantiatePSClassObjectFailed", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The hashtable supplied to the Desired State Configuration resource {0} is not valid. The key or value cannot be null or empty.
    ///  
    /// </summary>
    internal static string InvalidHashtable {
        get {
            return ResourceManager.GetString("InvalidHashtable", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The username supplied to the Desired State Configuration resource {0} is not valid. The username cannot be null or empty.
    ///  
    /// </summary>
    internal static string InvalidPassword {
        get {
            return ResourceManager.GetString("InvalidPassword", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The username supplied to the Desired State Configuration resource {0} is not valid. The username cannot be null or empty.
    ///  
    /// </summary>
    internal static string InvalidUserName {
        get {
            return ResourceManager.GetString("InvalidUserName", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Property {0} is not declared in PowerShell class {1}, but defined in its configuration instance.
    ///  
    /// </summary>
    internal static string PropertyNotDeclaredInPSClass {
        get {
            return ResourceManager.GetString("PropertyNotDeclaredInPSClass", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    PartialConfiguration '{0}' has a Refresh Mode set to Disabled which is not a valid mode for Partial Configurations. Use Pull or Push refresh mode. 
    ///  
    /// </summary>
    internal static string DisabledRefreshModeNotValidForPartialConfig {
        get {
            return ResourceManager.GetString("DisabledRefreshModeNotValidForPartialConfig", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot create type. Only core types are supported in this language mode.
    ///  
    /// </summary>
    internal static string CannotCreateTypeConstrainedLanguage {
        get {
            return ResourceManager.GetString("CannotCreateTypeConstrainedLanguage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Import-DscResource cannot be specified inside of Node context
    ///  
    /// </summary>
    internal static string ImportDscResourceInsideNode {
        get {
            return ResourceManager.GetString("ImportDscResourceInsideNode", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    $PSCulture, $PSUICulture, $true, $false, $null
    ///  
    /// </summary>
    internal static string DefaultAllowedVariablesInDataSection {
        get {
            return ResourceManager.GetString("DefaultAllowedVariablesInDataSection", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot assign automatic variable '{0}' with type '{1}'
    ///  
    /// </summary>
    internal static string AssignmentStatementToAutomaticNotSupported {
        get {
            return ResourceManager.GetString("AssignmentStatementToAutomaticNotSupported", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Conflict in using PsDscRunAsCredential for Resource {0} because it already specifies PsDscRunAsCredential value. We can only use one PsDscRunAsCredential for the composite resource. 
    ///  
    /// </summary>
    internal static string PsDscRunAsCredentialMergeErrorForCompositeResources {
        get {
            return ResourceManager.GetString("PsDscRunAsCredentialMergeErrorForCompositeResources", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Unable to find DSC schema store at "{0}". Please ensure PSDesiredStateConfiguration v3 module is installed.
    ///  
    /// </summary>
    internal static string PsDscMissingSchemaStore {
        get {
            return ResourceManager.GetString("PsDscMissingSchemaStore", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    {0}
    ///  
    /// </summary>
    internal static string ParserError {
        get {
            return ResourceManager.GetString("ParserError", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    This script contains content that has been flagged as suspicious through a policy setting and has been blocked with error code {0}. Contact your administrator for more information.
    ///  
    /// </summary>
    internal static string ScriptHasAdminBlockedContent {
        get {
            return ResourceManager.GetString("ScriptHasAdminBlockedContent", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Cannot use '&' or '.' operators to invoke a module scope command across language boundaries.
    ///  
    /// </summary>
    internal static string CantInvokeCallOperatorAcrossLanguageBoundaries {
        get {
            return ResourceManager.GetString("CantInvokeCallOperatorAcrossLanguageBoundaries", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Class keyword is not allowed in ConstrainedLanguage mode.
    ///  
    /// </summary>
    internal static string ClassesNotAllowedInConstrainedLanguage {
        get {
            return ResourceManager.GetString("ClassesNotAllowedInConstrainedLanguage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Missing ':' in the ternary expression.
    ///  
    /// </summary>
    internal static string MissingColonInTernaryExpression {
        get {
            return ResourceManager.GetString("MissingColonInTernaryExpression", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    A pipeline chain operator must be followed by a pipeline.
    ///  
    /// </summary>
    internal static string EmptyPipelineChainElement {
        get {
            return ResourceManager.GetString("EmptyPipelineChainElement", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Background operators can only be used at the end of a pipeline chain.
    ///  
    /// </summary>
    internal static string BackgroundOperatorInPipelineChain {
        get {
            return ResourceManager.GetString("BackgroundOperatorInPipelineChain", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Directly invoking the 'clean' block of a script block is not supported.
    ///  
    /// </summary>
    internal static string InvokingCleanBlockNotSupported {
        get {
            return ResourceManager.GetString("InvokingCleanBlockNotSupported", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Parser Configuration Keyword
    ///  
    /// </summary>
    internal static string WDACParserConfigKeywordLogTitle {
        get {
            return ResourceManager.GetString("WDACParserConfigKeywordLogTitle", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The Configuration keyword will not be allowed in Constrained Language mode for untrusted script.
    ///  
    /// </summary>
    internal static string WDACParserConfigKeywordLogMessage {
        get {
            return ResourceManager.GetString("WDACParserConfigKeywordLogMessage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Parser Class Keyword
    ///  
    /// </summary>
    internal static string WDACParserClassKeywordLogTitle {
        get {
            return ResourceManager.GetString("WDACParserClassKeywordLogTitle", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The Class keyword will not be allowed in Constrained Language mode for untrusted script.
    ///  
    /// </summary>
    internal static string WDACParserClassKeywordLogMessage {
        get {
            return ResourceManager.GetString("WDACParserClassKeywordLogMessage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Parser Data Section SupportedCommand
    ///  
    /// </summary>
    internal static string WDACParserDSSupportedCommandLogTitle {
        get {
            return ResourceManager.GetString("WDACParserDSSupportedCommandLogTitle", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The Data Section that includes the SupportedCommand parameter would be disallowed in Constrained Language mode for untrusted script.
    ///  
    /// </summary>
    internal static string WDACParserDSSupportedCommandLogMessage {
        get {
            return ResourceManager.GetString("WDACParserDSSupportedCommandLogMessage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Module Scope Call Operator
    ///  
    /// </summary>
    internal static string WDACParserModuleScopeCallOperatorLogTitle {
        get {
            return ResourceManager.GetString("WDACParserModuleScopeCallOperatorLogTitle", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The module scope call operator will be denied in Constrained Language mode.
    ///  
    /// </summary>
    internal static string WDACParserModuleScopeCallOperatorLogMessage {
        get {
            return ResourceManager.GetString("WDACParserModuleScopeCallOperatorLogMessage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    ForEach Keyword Method Invocation
    ///  
    /// </summary>
    internal static string WDACParserForEachOperatorLogTitle {
        get {
            return ResourceManager.GetString("WDACParserForEachOperatorLogTitle", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    The ForEach keyword will fail '{0}' iteration item method invocation when run in Constrained Language mode.
    ///  
    /// </summary>
    internal static string WDACParserForEachOperatorLogMessage {
        get {
            return ResourceManager.GetString("WDACParserForEachOperatorLogMessage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Expression Evaluation May Fail
    ///  
    /// </summary>
    internal static string WDACGetSteppablePipelineLogTitle {
        get {
            return ResourceManager.GetString("WDACGetSteppablePipelineLogTitle", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Creating a steppable pipeline from a script block may require evaluating some expressions within the script block. The expression evaluation will silently fail and return 'null' in Constrained Language mode, unless the expression represents a constant value.
    ///  
    /// </summary>
    internal static string WDACGetSteppablePipelineLogMessage {
        get {
            return ResourceManager.GetString("WDACGetSteppablePipelineLogMessage", resourceCulture);
        }
    }


    /// <summary>
    ///   Looks up a localized string similar to 
    ///    Configuration keyword is not supported on ARM64 processors.
    ///  
    /// </summary>
    internal static string ConfigurationNotAllowedOnArm64 {
        get {
            return ResourceManager.GetString("ConfigurationNotAllowedOnArm64", resourceCulture);
        }
    }

}

